==> jwinner-base-0.1.7-sources.jar: itez/plat/main/model/_MappingKit.java <==
package itez.plat.main.model;

import com.jfinal.plugin.activerecord.ActiveRecordPlugin;
import itez.core.wrapper.dbo.model.EMapping;
import itez.core.wrapper.dbo.model.IDataBaseConfig;
import itez.plat.main.DataBaseConfig;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
public class _MappingKit extends EMapping {

	@Override
	public IDataBaseConfig getDataBaseConfig() {
		return new DataBaseConfig();
	}

	@Override
	protected void mapping(ActiveRecordPlugin arp) {
		arp.addMapping("base_app_update", "id", AppUpdate.class);
		arp.addMapping("base_comp", "id", Comp.class);
		arp.addMapping("base_comp_bank", "id", CompBank.class);
		arp.addMapping("base_comp_wx", "id", CompWx.class);
		arp.addMapping("base_config", "id", Config.class);
		arp.addMapping("base_config_default", "id", ConfigDefault.class);
		arp.addMapping("base_config_group", "id", ConfigGroup.class);
		arp.addMapping("base_countor", "id", Countor.class);
		arp.addMapping("base_dept", "id", Dept.class);
		arp.addMapping("base_dict", "id", Dict.class);
		arp.addMapping("base_dict_group", "id", DictGroup.class);
		arp.addMapping("base_drawing_element", "id", DrawingElement.class);
		arp.addMapping("base_drawing_group", "id", DrawingGroup.class);
		arp.addMapping("base_drawing_model", "id", DrawingModel.class);
		arp.addMapping("base_form_cache", "id", FormCache.class);
		arp.addMapping("base_leaved", "id", Leaved.class);
		arp.addMapping("base_menu", "id", Menu.class);
		arp.addMapping("base_module", "id", Module.class);
		arp.addMapping("base_payment_channel", "id", PaymentChannel.class);
		arp.addMapping("base_perm", "id", Perm.class);
		arp.addMapping("base_post", "id", Post.class);
		arp.addMapping("base_post_level", "id", PostLevel.class);
		arp.addMapping("base_role", "id", Role.class);
		arp.addMapping("base_session", "id", Session.class);
		arp.addMapping("base_task", "id", Task.class);
		arp.addMapping("base_temp", "id", Temp.class);
		arp.addMapping("base_temp_group", "id", TempGroup.class);
		arp.addMapping("base_user", "id", User.class);
		arp.addMapping("base_vert", "id", Vert.class);
	}
}

==> jwinner-base-0.1.9-sources.jar: itez/plat/main/model/_MappingKit.java <==
package itez.plat.main.model;

import com.jfinal.plugin.activerecord.ActiveRecordPlugin;
import itez.core.wrapper.dbo.model.EMapping;
import itez.core.wrapper.dbo.model.IDataBaseConfig;
import itez.plat.main.DataBaseConfig;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
public class _MappingKit extends EMapping {

	@Override
	public IDataBaseConfig getDataBaseConfig() {
		return new DataBaseConfig();
	}

	@Override
	protected void mapping(ActiveRecordPlugin arp) {
		arp.addMapping("base_app_update", "id", AppUpdate.class);
		arp.addMapping("base_comp", "id", Comp.class);
		arp.addMapping("base_comp_bank", "id", CompBank.class);
		arp.addMapping("base_comp_wx", "id", CompWx.class);
		arp.addMapping("base_config", "id", Config.class);
		arp.addMapping("base_config_default", "id", ConfigDefault.class);
		arp.addMapping("base_config_group", "id", ConfigGroup.class);
		arp.addMapping("base_counter", "id", Counter.class);
		arp.addMapping("base_dept", "id", Dept.class);
		arp.addMapping("base_dept_type", "id", DeptType.class);
		arp.addMapping("base_dict", "id", Dict.class);
		arp.addMapping("base_dict_group", "id", DictGroup.class);
		arp.addMapping("base_drawing_element", "id", DrawingElement.class);
		arp.addMapping("base_drawing_group", "id", DrawingGroup.class);
		arp.addMapping("base_drawing_model", "id", DrawingModel.class);
		arp.addMapping("base_file_store", "id", FileStore.class);
		arp.addMapping("base_form_cache", "id", FormCache.class);
		arp.addMapping("base_leaved", "id", Leaved.class);
		arp.addMapping("base_menu", "id", Menu.class);
		arp.addMapping("base_module", "id", Module.class);
		arp.addMapping("base_payment_channel", "id", PaymentChannel.class);
		arp.addMapping("base_payment_isv", "id", PaymentIsv.class);
		arp.addMapping("base_perm", "id", Perm.class);
		arp.addMapping("base_policy_account", "id", PolicyAccount.class);
		arp.addMapping("base_policy_lock", "id", PolicyLock.class);
		arp.addMapping("base_policy_pwd", "id", PolicyPwd.class);
		arp.addMapping("base_post", "id", Post.class);
		arp.addMapping("base_post_level", "id", PostLevel.class);
		arp.addMapping("base_role", "id", Role.class);
		arp.addMapping("base_session", "id", Session.class);
		arp.addMapping("base_task", "id", Task.class);
		arp.addMapping("base_temp", "id", Temp.class);
		arp.addMapping("base_temp_group", "id", TempGroup.class);
		arp.addMapping("base_terminal", "id", Terminal.class);
		arp.addMapping("base_terminal_envs", "id", TerminalEnvs.class);
		arp.addMapping("base_tp_api", "id", TpApi.class);
		arp.addMapping("base_user", "id", User.class);
		arp.addMapping("base_user_oauth", "id", UserOauth.class);
		arp.addMapping("base_vert", "id", Vert.class);
	}
}
